@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import abc
+import base64
 import copy
 import filecmp
 import os
@@ -26,10 +27,10 @@ import netaddr
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils as agent_utils
 from neutron.common import rpc as n_rpc
-from neutron.plugins.common import utils as plugin_utils
 from neutron_lib.api import validators
 from neutron_lib import constants
 from neutron_lib import context
+from neutron_lib.plugins import utils as plugin_utils
 from neutron_lib.utils import file as file_utils
 from oslo_concurrency import lockutils
 from oslo_config import cfg
@@ -37,6 +38,7 @@ from oslo_log import helpers as log_helpers
 from oslo_log import log as logging
 import oslo_messaging
 from oslo_service import loopingcall
+from oslo_utils import encodeutils
 from oslo_utils import fileutils
 import six
 
@@ -111,6 +113,18 @@ JINJA_ENV = None
 
 IPSEC_CONNS = 'ipsec_site_connections'
 
+# *Swan supports Base64 encoded binary values as PSKs. In such cases,
+# a character sequence beginning with 0s is interpreted as Base64
+# encoded binary data.
+#   - StrongSwan
+#     - https://wiki.strongswan.org/projects/strongswan/wiki/PskSecret
+#   - LibreSwan
+#     - https://libreswan.org/man/ipsec.secrets.5.html
+#     - https://libreswan.org/man/ipsec_ttodata.3.html
+#   - OpenSwan (no online documents, see manpages sources in the repository)
+#     - https://github.com/xelerance/Openswan
+PSK_BASE64_PREFIX = '0s'
+
 
 def _get_template(template_file):
     global JINJA_ENV
@@ -151,6 +165,8 @@ class BaseSwanProcess(object):
         "aes-256": "aes256",
         "aes-192": "aes192",
         "sha256": "sha2_256",
+        "sha384": "sha2_384",
+        "sha512": "sha2_512",
         "group2": "modp1024",
         "group5": "modp1536",
         "group14": "modp2048",
@@ -168,9 +184,9 @@ class BaseSwanProcess(object):
     STATUS_RE = '\d\d\d "([a-f0-9\-]+).* (unrouted|erouted);'
     STATUS_NOT_RUNNING_RE = 'Command:.*ipsec.*status.*Exit code: [1|3]$'
     STATUS_IPSEC_SA_ESTABLISHED_RE = (
-        '\d{3} #\d+: "([a-f0-9\-]+).*established.*newest IPSEC')
+        '\d{3} #\d+: "([a-f0-9\-]+).*IPsec SA established.*')
     STATUS_IPSEC_SA_ESTABLISHED_RE2 = (
-        '\d{3} #\d+: "([a-f0-9\-\/x]+).*established.*newest IPSEC')
+        '\d{3} #\d+: "([a-f0-9\-\/x]+).*IPsec SA established.*')
 
     def __init__(self, conf, process_id, vpnservice, namespace):
         self.conf = conf
@@ -207,9 +223,23 @@ class BaseSwanProcess(object):
                 (not ipsec_site_conn['local_id'])):
                 ipsec_site_conn['local_id'] = ipsec_site_conn['external_ip']
 
+    def base64_encode_psk(self):
+        if not self.vpnservice:
+            return
+        for ipsec_site_conn in self.vpnservice['ipsec_site_connections']:
+            psk = ipsec_site_conn['psk']
+            encoded_psk = base64.b64encode(encodeutils.safe_encode(psk))
+            # NOTE(huntxu): base64.b64encode returns an instance of 'bytes'
+            # in Python 3, convert it to a str. For Python 2, after calling
+            # safe_decode, psk is converted into a unicode not containing any
+            # non-ASCII characters so it doesn't matter.
+            psk = encodeutils.safe_decode(encoded_psk, incoming='utf_8')
+            ipsec_site_conn['psk'] = PSK_BASE64_PREFIX + psk
+
     def update_vpnservice(self, vpnservice):
         self.vpnservice = vpnservice
         self.translate_dialect()
+        self.base64_encode_psk()
 
     def _dialect(self, obj, key):
         obj[key] = self.DIALECT_MAP.get(obj[key], obj[key])
@@ -782,7 +812,7 @@ class IPsecDriver(device_drivers.DeviceDriver):
         # implementations no longer need vpn_service.
         self.conf = vpn_service.conf
         self.host = host
-        self.conn = n_rpc.create_connection()
+        self.conn = n_rpc.Connection()
         self.context = context.get_admin_context_without_session()
         self.topic = topics.IPSEC_AGENT_TOPIC
         node_topic = '%s.%s' % (self.topic, self.host)
