@@ -3,7 +3,9 @@
 set -ex
 
 VENV=${1:-"dsvm-functional"}
-export DEVSTACK_LOCAL_CONFIG="enable_plugin neutron-vpnaas https://git.openstack.org/openstack/neutron-vpnaas"
+DEVSTACK_LOCAL_CONFIG="NETWORK_API_EXTENSIONS=all"
+DEVSTACK_LOCAL_CONFIG+=$'\n'"enable_plugin neutron-vpnaas https://git.openstack.org/openstack/neutron-vpnaas"
+export DEVSTACK_LOCAL_CONFIG
 
 case $VENV in
     dsvm-functional | dsvm-functional-sswan)
@@ -25,5 +27,7 @@ case $VENV in
 
         configure_host_for_vpn_func_testing
         ;;
-    api) $BASE/new/devstack-gate/devstack-vm-gate.sh ;;
+    api|tempest)
+        $BASE/new/devstack-gate/devstack-vm-gate.sh
+        ;;
 esac
